@@ -23,7 +23,6 @@ use warnings;
 use Carp qw(carp confess croak);
 use Digest::SHA 'sha1_hex';
 use Exporter 5.57 'import';     # exported import method
-use File::ShareDir 'dist_file';
 use LWP::UserAgent 6 ();
 use Scalar::Util 1.01 'reftype';
 use Try::Tiny 0.04;
@@ -31,7 +30,7 @@ use Try::Tiny 0.04;
 #=====================================================================
 # Package Global Variables:
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 our @EXPORT_OK = qw(_eval _eval_or_die);
 
@@ -40,10 +39,8 @@ our $saltAlphabet
 
 our $ua = LWP::UserAgent->new(
   agent => "WebService-NFSN/$VERSION ",
-  # If LWP 6, verify the server's cert using NFSN's internal CA cert:
   ssl_opts => {
     verify_hostname => 1,
-    SSL_ca_file => dist_file(qw(WebService-NFSN nfsn-ca.crt)),
   },
 );
 
@@ -309,9 +306,9 @@ WebService::NFSN - Client for the NearlyFreeSpeech.NET API
 
 =head1 VERSION
 
-This document describes version 1.02 of
-WebService::NFSN, released December 21, 2011
-as part of WebService-NFSN version 1.02.
+This document describes version 1.03 of
+WebService::NFSN, released April 30, 2014
+as part of WebService-NFSN version 1.03.
 
 =head1 SYNOPSIS
 
@@ -525,11 +522,11 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=WebService-NFSN >>.
 
 You can follow or contribute to WebService-NFSN's development at
-L<< http://github.com/madsen/webservice-nfsn >>.
+L<< https://github.com/madsen/webservice-nfsn >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Christopher J. Madsen.
+This software is copyright (c) 2014 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
